use strict;
use warnings;

use Test::More tests => 4;

BEGIN { use_ok('App::Virtualenv') }
BEGIN { use_ok('App::Virtualenv::Utils') }
BEGIN { use_ok('App::Virtualenv::Module') }
BEGIN { use_ok('App::Virtualenv::Piv') }
